@@ -552,9 +552,9 @@ Usage : Pass the Subplots of a Plot separated by comma in any order to get All t
 
 if __name__ == '__main__' :
 
-    #FILE_NAME='tplots.xlsx'
+    FILE_NAME='tplots.xlsx'
     #FILE_NAME='plotdata'
     #FILE_NAME='plot1.xlsx'
     #agriplot(FILE_NAME, checkfile='done' )
-    #agriplot(FILE_NAME )
+    agriplot(FILE_NAME )
     
